html {
    overflow-x: hidden;
}

body {
    background-color: rgb(22, 22, 22);
    color: white;
    font-family: Arial, Helvetica, sans-serif;
    display: grid;
    place-items: center;
    height: 100vh;
    margin: 0;
}

a {
    background: linear-gradient(90deg, #ff00ae, #ff65ce);
    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
    text-decoration: none;
    font-weight: bold;
    transition: 0.2s ease;
}

a:hover {
    text-shadow: 0 0 10px #ff00ae, 0 0 20px #ff65ce;
}

#header {
    text-align: center;
    font-size: 50px;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-bottom: 1rem;
}

#img_content {
    height: 350px;
    width: 350px;
}

#content {
    text-align: center;
    font-size: 30px;
    display: flex;
    align-items: center;
    justify-content: center;
}

code {
    background-color: rgb(10, 10, 10);
    border-radius: 8px;
    padding: 0.5rem;
    font-family: monospace !important;
    font-weight: bold;
    text-decoration: underline;
    box-shadow: 0 15px 30px rgba(0, 0, 0, 0.3);
}

#img {
    height: 100px;
    width: 100px;
    text-align: center;
    font-size: large;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-left: 450px;
    animation: rotate 6s linear infinite;
}

@keyframes rotate {
    0% {
        transform: rotate(0deg);
    }
    100% {
        transform: rotate(360deg);
    }
}
